@@ -1,5 +1,7 @@
 pub mod lexer;
+pub mod iter;
 use crate::lexer::*;
+use crate::iter::MiniIter;
 
 #[derive(Debug)]
 pub(crate) struct SanitizationError{
@@ -8,60 +10,60 @@ pub(crate) struct SanitizationError{
 
 /// Convert source markdown to an ordered vector of tokens
 pub fn lex(source: &str) -> Vec<Token>{
-    let mut char_iter = source.chars().peekable();
+    let mut char_iter = MiniIter::new(source);
     let mut tokens = Vec::new();
     while char_iter.peek().is_some(){
         match char_iter.peek().unwrap(){
-            '#' => {
+            "#" => {
                 let token = lex_heading(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '*' | '_' => {
+            "*" | "_" => {
                 let token = lex_asterisk_underscore(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '~' => {
+            "~" => {
                 let token = lex_tilde(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '-' | '+' => {
+            "-" | "+" => {
                 let token = lex_plus_minus(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            ' ' => {
+            " " => {
                 let token = lex_spaces(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '`' => {
+            "`" => {
                 let token = lex_backticks(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '\n' => {
+            "\n" => {
                 let token = lex_newlines(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '>' => {
+            ">" => {
                 let token = lex_blockquotes(&mut char_iter);
                 match token {
                     Ok(t) => {
@@ -70,52 +72,52 @@ pub fn lex(source: &str) -> Vec<Token>{
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '!' => {
+            "!" => {
                 let token = lex_images(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '[' => {
+            "[" => {
                 let token = lex_links(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '<' => {
+            "<" => {
                 let token = lex_side_carrot(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '|' => {
+            "|" => {
                 let token = lex_pipes(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             },
-            '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9' | '0' => {
+            "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "0" => {
                 let token = lex_numbers(&mut char_iter);
                 match token {
                     Ok(t) => tokens.push(t),
                     Err(e) => push_str(&mut tokens, e.content),
                 }
             }
-            // Parse '\' to escape a markdown control character
-            '\\' => {
+            // Parse "\" to escape a markdown control character
+            "\\" => {
                 char_iter.next();
                 if char_iter.peek().is_some(){
                     let c = char_iter.next().unwrap();
-                    push_char(&mut tokens, c);
+                    push_str(&mut tokens, c);
                 }
             }
             _ => {
                 let c = char_iter.next().unwrap();
-                push_char(&mut tokens, c);
+                push_str(&mut tokens, c);
             },
         }
     }
@@ -246,8 +248,6 @@ pub fn parse(tokens: &[Token]) -> String {
             Token::LineBreak => {html.push_str("<br>")},
             Token::HorizontalRule => {html.push_str("<hr />")},
             Token::Strikethrough(t) => {html.push_str(format!("<strike>{}</strike>", sanitize_display_text(t)).as_str())},
-            // Token::Tab => {},
-            // Token::DoubleTab => {},
             Token::Code(t) => {html.push_str(format!("<code>{}</code>", sanitize_display_text(t)).as_str())},
             Token::CodeBlock(t, lang) => {
                 html.push_str(format!(
@@ -258,7 +258,7 @@ pub fn parse(tokens: &[Token]) -> String {
             },
             Token::BlockQuote(l, t) => {
                 if in_paragraph {
-                    html.push_str(format!("</p>").as_str());
+                    html.push_str("</p>");
                     in_paragraph = false;
                 }
                 match quote_level {
@@ -309,11 +309,15 @@ pub fn parse(tokens: &[Token]) -> String {
                 }
             },
             Token::Detail(summary, inner_tokens) => {
+                if in_paragraph {
+                    html.push_str("</p>\n");
+                    in_paragraph = false;
+                }
                 let inner_html = parse(inner_tokens);
                 html.push_str(format!("<details>\n<summary>{sum}</summary>\n{in_html}\n</details>", sum=sanitize_display_text(summary), in_html=inner_html).as_str());
             },
             Token::Table(headings, rows) => {
-                //Assert headings.len() == rows.width()
+                if  headings.len() != rows[0].len() {continue}
                 html.push_str("<table class=\"table table-bordered\">\n\t<thead>\n\t<tr>\n");
                 for h in headings.into_iter() {
                     html.push_str(format!("\t\t<th style=\"text-align: {align}\">{heading}</th>", heading=sanitize_display_text(&h.1), align=h.0).as_str());
